/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.expression.function;

import java.sql.SQLException;
import java.util.List;

import org.apache.phoenix.expression.Expression;
import org.apache.phoenix.parse.FunctionParseNode.Argument;
import org.apache.phoenix.parse.FunctionParseNode.BuiltInFunction;
import org.apache.phoenix.schema.PDataType;


/**
 * 
 * Function used to bucketize date/time values by truncating them to
 * an even increment.  Usage:
 * TRUNC(<date/time col ref>,<'day'|'hour'|'minute'|'second'|'millisecond'>,[<optional integer multiplier>])
 * The integer multiplier is optional and is used to do rollups to a partial time unit (i.e. 10 minute rollup)
 * The function returns a {@link org.apache.phoenix.schema.PDataType#DATE}
 *
 * 
 * @since 0.1
 */
@BuiltInFunction(name="TRUNC", args= {
    @Argument(allowedTypes={PDataType.TIME}),
    @Argument(enumeration="TimeUnit"),
    @Argument(allowedTypes={PDataType.INTEGER}, isConstant=true, defaultValue="1")} )
public class TruncFunction extends RoundFunction {
    public TruncFunction() {
    }
    
    public TruncFunction(List<Expression> node) throws SQLException {
        super(node);
    }
    
    @Override
    protected long getRoundUpAmount() {
        return 0;
    }
}
